/***************************************************************************
 * Project: CMS detector at the LHC, CERN
 * Package: RooFit
 *    File: $Id$
 * Authors:
 *   Giordano Cerizza
 *   
 * History:
 *   08-15-2008 TS started
 *
 *****************************************************************************/
#include <map>
#include <string>
#include "RooFit.h"
#include "Riostream.h"
#include "RooNLLVar.h"
#include "RooMinuit.h"
#include "RooFitResult.h"
#include "Riostream.h"
#include "RooAbsReal.h"
#include "RooRealVar.h"
#include "RooFormulaVar.h"
#include "RooFormula.h"
#include "RooGenericPdf.h"
#include "TNtupleD.h"
#include "RooStringVar.h"
#include "TCanvas.h"
#include "TArrow.h"
#include "TDirectory.h"
#include "TROOT.h"
#include "RooFit.h"
#include "RooArgList.h"
#include "RooAddPdf.h"
#include "RooRandom.h"
#include "Riostream.h"
#include "RooRealVar.h"
#include "RooPlot.h"
#include "TCanvas.h"
#include "TH1.h"
#include "TFile.h"
#include "RooAddPdf.h"
#include "RooAbsReal.h"
#include "RooAddModel.h"
#include "RooProdPdf.h"
#include "RooGaussian.h"
#include "RooLandau.h"
#include "RooVoigtian.h"
#include "RooBreitWigner.h"
#include "RooBifurGauss.h"
#include "RooArgusBG.h"
#include "RooGaussModel.h"
#include "RooNovosibirsk.h"
#include "RooPolynomial.h"
#include "RooExponential.h"
#include "RooFFTConvPdf.h"
#include "RooJpsiPhiFit/RooCPjpsiphiFit.hh"
#include "RooJpsiPhiFit/RooDecayRateDoubleExpoCos2.hh"
#include "RooGaussModel.h"
#include "RooGExpModel.h"
#include "RooLandau.h"
#include "RooDecay.h"
#include "RooMCStudy.h"
#include "RooGlobalFunc.h"
#include "RooChebychev.h"
#include "TApplication.h"
using namespace RooFit;

RooCPjpsiphiFit::RooCPjpsiphiFit()  { 

  cout << " //////////////////////////////////////////////////// " << endl;
  cout << " //                                                // " << endl;
  cout << " //                J/Psi Phi Fitter                // " << endl;
  cout << " //                                                // " << endl;
  cout << " // Author:    Giordano Cerizza                    // " << endl; 
  cout << " //                                                // " << endl;
  cout << " // Institute: University of Tennessee             // " << endl;
  cout << " //            401 Nielsen Physics Building        // " << endl;
  cout << " //            1408 Circle Drive                   // " << endl;
  cout << " //            Knoxville, TN 37996-1200            // " << endl;
  cout << " //                                                // " << endl;
  cout << " // email:     gcerizza@utk.edu                    // " << endl;   
  cout << " //                                                // " << endl;
  cout << " //////////////////////////////////////////////////// " << endl;

  initDataVars();
}

RooCPjpsiphiFit::~RooCPjpsiphiFit()  { }

void 
RooCPjpsiphiFit::initDataVars() {

  cout << "RooCPjpsiphiFit: Initialization Data Variables" << endl ;

  genCtau = new RooRealVar("genCtau","genCtau",0,0.35) ;
  costhetaMC = new RooRealVar("costhetaMC","costhetaMC",-1.,1.) ;

  dataVars.add(RooArgSet(*genCtau,*costhetaMC));
  _initDataVars = kTRUE ;
  
}

void
RooCPjpsiphiFit::pureMCtoysGeneration() {

  cout << "RooCPjpsiphiFits: Toy Experiment Generator" << endl;

  ////////////////////////////////////////////
  //  TOY parameters
  ////////////////////////////////////////////

  GL = new RooRealVar("GH","",0.04483); //,0.,0.1);
  GH = new RooRealVar("GL","",0.04277); //,0.,0.1);
  //  avgG = new RooRealVar("avgG","",0.0438,0.,0.1);
  //  dG = new RooRealVar("dG","",0.0020556,0.001,0.01);
  CPfrac = new RooRealVar("CPfrac","",0.8407); //,0.,1.);

  ////////////////////////////////////////////
  //  TOY pdf
  ////////////////////////////////////////////

  RooDecayRateDoubleExpoCos2 model("model","",*genCtau,*costhetaMC,*GL,*GH,*CPfrac);

  ////////////////////////////////
  // MC toy run manager
  ////////////////////////////////

  RooAbsData *data= model.generate(RooArgSet(*genCtau,*costhetaMC),1000);
  //  model.fitTo(*data);
  
  RooPlot* frame1 = genCtau->frame(Title("proper decay length"));
  frame1 = genCtau->frame(35);
  model.plotOn(frame1);
  data->plotOn(frame1);

  TCanvas* c1 = new TCanvas("c1","",10,10,700,500) ;
  c1->cd();
  c1->SetFillColor(kWhite);
  frame1->SetXTitle("ctau (cm)");
  frame1->Draw();

  RooPlot* frame2 = costhetaMC->frame(Title("costheta"));
  frame2 = costhetaMC->frame(35);
  model.plotOn(frame2);
  data->plotOn(frame2);

  TCanvas* c2 = new TCanvas("c2","",20,20,700,500) ;
  c2->cd();
  c2->SetFillColor(kWhite);
  frame2->SetXTitle("costheta");
  frame2->Draw();

}

