/*****************************************************************************
 * Project: RooFit                                                           *
 * Package: RooFitModels                                                     *
 *    File: $Id: RooExponential.cc,v 1.15 2005/06/20 15:51:06 wverkerke Exp $
 * Authors:                                                                  *
 *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
 *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
 *                                                                           *
 * Copyright (c) 2000-2005, Regents of the University of California          *
 *                          and Stanford University. All rights reserved.    *
 *                                                                           *
 * Redistribution and use in source and binary forms,                        *
 * with or without modification, are permitted according to the terms        *
 * listed in LICENSE (http://roofit.sourceforge.net/license.txt)             *
 *****************************************************************************/

// -- CLASS DESCRIPTION [PDF] --

#include "TMath.h"
#include "RooFit.h"

#include "Riostream.h"
#include "Riostream.h"
#include <math.h>

#include "tmp/RooJpsiPhiFit/RooDecayRateDoubleExpoCos2.hh"
#include "RooRealVar.h"
#include "RooArgSet.h"
#include "RooRealConstant.h"

ClassImp(RooDecayRateDoubleExpoCos2)
 
RooDecayRateDoubleExpoCos2::RooDecayRateDoubleExpoCos2(const char *name, const char *title, RooAbsReal& _length, RooAbsReal& _costheta, 
						     RooAbsReal& _GL, RooAbsReal& _GH, RooAbsReal& _p_0) :
  RooAbsPdf(name, title), 
  length("length","Dependent",this,_length),
  costheta("costheta","Dependent",this,_costheta),
  GL("GL","Parameter",this,_GL),
  GH("GH","Parameter",this,_GH),
  p_0("p_0","Parameter",this,_p_0),
  _x("x","Observables",this,kTRUE,kFALSE)

{
  _x.add(_length);
  _x.add(_costheta);
}
 
RooDecayRateDoubleExpoCos2::RooDecayRateDoubleExpoCos2(const RooDecayRateDoubleExpoCos2& other, const char *name) :
  
  RooAbsPdf(other, name), 
  length("length",this,other.length),
  costheta("costheta",this,other.costheta),
  GL("GL",this,other.GL),
  GH("GH",this,other.GH),
  p_0("p_0",this,other.p_0),
  _x("x",this,other._x)  
  
{
}

Double_t RooDecayRateDoubleExpoCos2::evaluate() const{
  
  return  p_0*exp(-(1/GL)*length)*(1+costheta*costheta)+(2.)*(1-p_0)*exp(-(1/GH)*length)*(1-costheta*costheta);
  
}

Int_t RooDecayRateDoubleExpoCos2::getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVars, const char* rangeName) const 
{
  if (matchArgs(allVars,analVars,_x)) return 1;
  if (matchArgs(allVars,analVars,length)) return 2;
  if (matchArgs(allVars,analVars,costheta)) return 3;
  else
    return 0 ;
}

Double_t RooDecayRateDoubleExpoCos2::analyticalIntegral(Int_t code, const char* rangeName) const 
{
  switch(code) {
  case 1:
    return (8/3)*p_0*GL+(8/3)*(1-p_0)*GH;
  case 2:
    return (8/3)*p_0*exp(-(1/GL)*length)+(8/3)*(1-p_0)*exp(-(1/GH)*length);
  case 3:
    return p_0*GL*(1+costheta*costheta)+(1-p_0)*GH*(2.)*(1-costheta*costheta);
  default:
    assert(0);
  }
  
  return 0 ;

}

